import { Tab } from "@headlessui/react";
import React, { useEffect, useRef, useState } from "react";
import { useUpdatePasswordMutation } from "../../app/features/userDashboard/apiSlice";
import { toast } from "react-toastify";
import { language } from "../../app/features/websiteSetup/websiteSetupSlice";
import useLanguage from "../../hooks/useLanguage";

function ChangePassword() {
  const [updatePassword, { error, isLoading }] = useUpdatePasswordMutation();
  const [password, setPassword] = useState({
    current_password: "",
    password: "",
    password_confirmation: "",
  });
  const handleUpdatePassword = (e) => {
    e.preventDefault();
    if (password.password === password.password_confirmation) {
      updatePassword(password);
    } else {
      toast.error("Password an confirm password should same");
    }
  };

  handleUpdatePassword.bind(this);

  const handleChange = (e) => {
    setPassword((prev) => ({ ...prev, [e.target.name]: e.target.value }));
  };
  handleChange.bind(this);
  const language = useLanguage();
  return (
    <Tab.Panel>
      <h3 className="text-2xl text-dark-300 font-bold mb-4 notranslate">
        {language["Change Password"]}
      </h3>
      <div className="rounded border border-primary-100 px-5 py-7 ">
        <div className="lg:w-1/2 w-full">
          <form onSubmit={handleUpdatePassword}>
            <div className="grid gap-5">
              <div>
                <label className="text-dark-200 text-sm mb-1 block notranslate">
                  {language["Current Password"]}
                </label>
                <div className="relative">
                  <input
                    type="password"
                    name="current_password"
                    value={password.current_password}
                    onChange={handleChange}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="********"
                  />
                  <button
                    onClick={(e) => {
                      e.preventDefault();
                      if (e.target.previousElementSibling.type === "password") {
                        e.target.previousElementSibling.type = "text";
                      } else {
                        e.target.previousElementSibling.type = "password";
                      }
                    }}
                    className="absolute inset-y-0 flex items-center justify-center right-4 "
                  >
                    <svg
                      className="pointer-events-none"
                      xmlns="http://www.w3.org/2000/svg"
                      width="25"
                      height="21"
                      viewBox="0 0 25 21"
                      fill="none"
                    >
                      <g clipPath="url(#clip0_325_3371)">
                        <path
                          d="M20.5488 16.3521C20.1565 15.9555 19.7701 15.5603 19.3807 15.168C18.7806 14.5651 18.1791 13.9636 17.5733 13.3664C17.4977 13.2909 17.4876 13.2386 17.5384 13.1412C19.3487 9.66013 17.213 5.45984 13.3337 4.87723C12.1148 4.69417 10.9539 4.89612 9.8584 5.46274C9.78721 5.49906 9.73636 5.53539 9.65645 5.45548C8.88206 4.67237 8.10185 3.89653 7.3231 3.11779C7.3013 3.09599 7.28387 3.07129 7.24609 3.02625C7.56718 2.90567 7.86939 2.78362 8.17885 2.67902C10.0763 2.03539 12.0247 1.83489 14.0137 2.05137C18.8794 2.58312 23.1757 5.85357 24.9773 10.3924C25.0005 10.452 25.0078 10.5377 24.9831 10.5958C24.0488 12.8913 22.596 14.7917 20.6287 16.2984C20.6142 16.3114 20.5968 16.3216 20.5488 16.3521Z"
                          fill="#65656C"
                        />
                        <path
                          d="M4.44163 4.65942C4.91528 5.13597 5.3773 5.60235 5.84222 6.06727C6.36962 6.59467 6.89703 7.12352 7.42733 7.64801C7.49853 7.71775 7.51015 7.76715 7.4622 7.86013C5.81462 11.0231 7.40118 14.8732 10.801 15.9338C12.2829 16.3958 13.7271 16.2578 15.1161 15.5575C15.1626 15.5343 15.2076 15.5096 15.2468 15.4892C16.0735 16.3188 16.893 17.1426 17.724 17.978C17.6862 17.9955 17.6383 18.0202 17.5874 18.0405C15.5069 18.8846 13.3493 19.1912 11.1162 18.966C6.18511 18.4676 1.87 15.2277 0.02773 10.6366C0.000124928 10.5669 -0.0114982 10.4695 0.0146539 10.4041C0.941602 8.1231 2.38433 6.23435 4.33557 4.73352C4.36317 4.71028 4.39514 4.69139 4.44163 4.65942Z"
                          fill="#65656C"
                        />
                        <path
                          d="M2.04297 1.0577C2.36406 0.732254 2.72292 0.370486 3.09051 0C9.71717 6.64695 16.3482 13.2968 22.9749 19.9438C22.645 20.2721 22.2833 20.631 21.9128 21C15.2905 14.3531 8.66237 7.70174 2.04297 1.0577Z"
                          fill="#65656C"
                        />
                        <path
                          d="M13.5452 13.7327C12.6531 14.0712 11.1145 14.016 10.0074 12.8435C9.16469 11.9515 8.80001 10.3286 9.2693 9.46411C10.696 10.8879 12.1141 12.3031 13.5452 13.7327Z"
                          fill="#65656C"
                        />
                        <path
                          d="M11.5195 7.24705C12.3128 6.80828 13.943 7.17296 14.8394 8.01418C16.0177 9.11982 16.0715 10.6642 15.7533 11.4938C14.3425 10.0802 12.9274 8.66071 11.5195 7.24705Z"
                          fill="#65656C"
                        />
                      </g>
                      <defs>
                        <clipPath id="clip0_325_3371">
                          <rect width="25" height="21" fill="white" />
                        </clipPath>
                      </defs>
                    </svg>
                  </button>
                </div>
              </div>{" "}
              <div>
                <label className="text-dark-200 text-sm mb-1 block notranslate">
                  {language["New Password"]}
                </label>
                <div className="relative">
                  <input
                    type="password"
                    name="password"
                    value={password.password}
                    onChange={handleChange}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="********"
                  />
                  <button
                    onClick={(e) => {
                      e.preventDefault();
                      if (e.target.previousElementSibling.type === "password") {
                        e.target.previousElementSibling.type = "text";
                      } else {
                        e.target.previousElementSibling.type = "password";
                      }
                    }}
                    className="absolute inset-y-0 flex items-center justify-center right-4 "
                  >
                    <svg
                      className="pointer-events-none"
                      xmlns="http://www.w3.org/2000/svg"
                      width="25"
                      height="21"
                      viewBox="0 0 25 21"
                      fill="none"
                    >
                      <g clipPath="url(#clip0_325_3371)">
                        <path
                          d="M20.5488 16.3521C20.1565 15.9555 19.7701 15.5603 19.3807 15.168C18.7806 14.5651 18.1791 13.9636 17.5733 13.3664C17.4977 13.2909 17.4876 13.2386 17.5384 13.1412C19.3487 9.66013 17.213 5.45984 13.3337 4.87723C12.1148 4.69417 10.9539 4.89612 9.8584 5.46274C9.78721 5.49906 9.73636 5.53539 9.65645 5.45548C8.88206 4.67237 8.10185 3.89653 7.3231 3.11779C7.3013 3.09599 7.28387 3.07129 7.24609 3.02625C7.56718 2.90567 7.86939 2.78362 8.17885 2.67902C10.0763 2.03539 12.0247 1.83489 14.0137 2.05137C18.8794 2.58312 23.1757 5.85357 24.9773 10.3924C25.0005 10.452 25.0078 10.5377 24.9831 10.5958C24.0488 12.8913 22.596 14.7917 20.6287 16.2984C20.6142 16.3114 20.5968 16.3216 20.5488 16.3521Z"
                          fill="#65656C"
                        />
                        <path
                          d="M4.44163 4.65942C4.91528 5.13597 5.3773 5.60235 5.84222 6.06727C6.36962 6.59467 6.89703 7.12352 7.42733 7.64801C7.49853 7.71775 7.51015 7.76715 7.4622 7.86013C5.81462 11.0231 7.40118 14.8732 10.801 15.9338C12.2829 16.3958 13.7271 16.2578 15.1161 15.5575C15.1626 15.5343 15.2076 15.5096 15.2468 15.4892C16.0735 16.3188 16.893 17.1426 17.724 17.978C17.6862 17.9955 17.6383 18.0202 17.5874 18.0405C15.5069 18.8846 13.3493 19.1912 11.1162 18.966C6.18511 18.4676 1.87 15.2277 0.02773 10.6366C0.000124928 10.5669 -0.0114982 10.4695 0.0146539 10.4041C0.941602 8.1231 2.38433 6.23435 4.33557 4.73352C4.36317 4.71028 4.39514 4.69139 4.44163 4.65942Z"
                          fill="#65656C"
                        />
                        <path
                          d="M2.04297 1.0577C2.36406 0.732254 2.72292 0.370486 3.09051 0C9.71717 6.64695 16.3482 13.2968 22.9749 19.9438C22.645 20.2721 22.2833 20.631 21.9128 21C15.2905 14.3531 8.66237 7.70174 2.04297 1.0577Z"
                          fill="#65656C"
                        />
                        <path
                          d="M13.5452 13.7327C12.6531 14.0712 11.1145 14.016 10.0074 12.8435C9.16469 11.9515 8.80001 10.3286 9.2693 9.46411C10.696 10.8879 12.1141 12.3031 13.5452 13.7327Z"
                          fill="#65656C"
                        />
                        <path
                          d="M11.5195 7.24705C12.3128 6.80828 13.943 7.17296 14.8394 8.01418C16.0177 9.11982 16.0715 10.6642 15.7533 11.4938C14.3425 10.0802 12.9274 8.66071 11.5195 7.24705Z"
                          fill="#65656C"
                        />
                      </g>
                      <defs>
                        <clipPath id="clip0_325_3371">
                          <rect width="25" height="21" fill="white" />
                        </clipPath>
                      </defs>
                    </svg>
                  </button>
                </div>
              </div>{" "}
              <div>
                <label className="text-dark-200 text-sm mb-1 block notranslate">
                  {language["Confirm Password"]}
                </label>
                <div className="relative">
                  <input
                    type="password"
                    name="password_confirmation"
                    value={password.password_confirmation}
                    onChange={handleChange}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="********"
                  />
                  <button
                    onClick={(e) => {
                      e.preventDefault();
                      if (e.target.previousElementSibling.type === "password") {
                        e.target.previousElementSibling.type = "text";
                      } else {
                        e.target.previousElementSibling.type = "password";
                      }
                    }}
                    className="absolute inset-y-0 flex items-center justify-center right-4 "
                  >
                    <svg
                      className="pointer-events-none"
                      xmlns="http://www.w3.org/2000/svg"
                      width="25"
                      height="21"
                      viewBox="0 0 25 21"
                      fill="none"
                    >
                      <g clipPath="url(#clip0_325_3371)">
                        <path
                          d="M20.5488 16.3521C20.1565 15.9555 19.7701 15.5603 19.3807 15.168C18.7806 14.5651 18.1791 13.9636 17.5733 13.3664C17.4977 13.2909 17.4876 13.2386 17.5384 13.1412C19.3487 9.66013 17.213 5.45984 13.3337 4.87723C12.1148 4.69417 10.9539 4.89612 9.8584 5.46274C9.78721 5.49906 9.73636 5.53539 9.65645 5.45548C8.88206 4.67237 8.10185 3.89653 7.3231 3.11779C7.3013 3.09599 7.28387 3.07129 7.24609 3.02625C7.56718 2.90567 7.86939 2.78362 8.17885 2.67902C10.0763 2.03539 12.0247 1.83489 14.0137 2.05137C18.8794 2.58312 23.1757 5.85357 24.9773 10.3924C25.0005 10.452 25.0078 10.5377 24.9831 10.5958C24.0488 12.8913 22.596 14.7917 20.6287 16.2984C20.6142 16.3114 20.5968 16.3216 20.5488 16.3521Z"
                          fill="#65656C"
                        />
                        <path
                          d="M4.44163 4.65942C4.91528 5.13597 5.3773 5.60235 5.84222 6.06727C6.36962 6.59467 6.89703 7.12352 7.42733 7.64801C7.49853 7.71775 7.51015 7.76715 7.4622 7.86013C5.81462 11.0231 7.40118 14.8732 10.801 15.9338C12.2829 16.3958 13.7271 16.2578 15.1161 15.5575C15.1626 15.5343 15.2076 15.5096 15.2468 15.4892C16.0735 16.3188 16.893 17.1426 17.724 17.978C17.6862 17.9955 17.6383 18.0202 17.5874 18.0405C15.5069 18.8846 13.3493 19.1912 11.1162 18.966C6.18511 18.4676 1.87 15.2277 0.02773 10.6366C0.000124928 10.5669 -0.0114982 10.4695 0.0146539 10.4041C0.941602 8.1231 2.38433 6.23435 4.33557 4.73352C4.36317 4.71028 4.39514 4.69139 4.44163 4.65942Z"
                          fill="#65656C"
                        />
                        <path
                          d="M2.04297 1.0577C2.36406 0.732254 2.72292 0.370486 3.09051 0C9.71717 6.64695 16.3482 13.2968 22.9749 19.9438C22.645 20.2721 22.2833 20.631 21.9128 21C15.2905 14.3531 8.66237 7.70174 2.04297 1.0577Z"
                          fill="#65656C"
                        />
                        <path
                          d="M13.5452 13.7327C12.6531 14.0712 11.1145 14.016 10.0074 12.8435C9.16469 11.9515 8.80001 10.3286 9.2693 9.46411C10.696 10.8879 12.1141 12.3031 13.5452 13.7327Z"
                          fill="#65656C"
                        />
                        <path
                          d="M11.5195 7.24705C12.3128 6.80828 13.943 7.17296 14.8394 8.01418C16.0177 9.11982 16.0715 10.6642 15.7533 11.4938C14.3425 10.0802 12.9274 8.66071 11.5195 7.24705Z"
                          fill="#65656C"
                        />
                      </g>
                      <defs>
                        <clipPath id="clip0_325_3371">
                          <rect width="25" height="21" fill="white" />
                        </clipPath>
                      </defs>
                    </svg>
                  </button>
                </div>
              </div>
              <div>
                <button
                  type="submit"
                  className="rounded bg-primary-200 font-medium text-base hover:bg-primary-200/80 text-white transition py-4 px-5 text-center w-full notranslate"
                >
                  {language["Update Password"]}
                </button>
              </div>
            </div>
          </form>
        </div>
      </div>
    </Tab.Panel>
  );
}

export default ChangePassword;
